@@ -67,7 +67,7 @@ class Servico:
         }
         query_params.update(filter_params)
         valor_padrao = {'inicio_execucao': environ.get('DATA_PADRAO_INTEGRACAO')}
-        response = Status.get(filter_params)
+        response = Status.get(query_params)
         data = response.json()[0] if response.ok and response.json() else valor_padrao
         data = make_aware(datetime.strptime(data.get('inicio_execucao'), '%Y-%m-%dT%H:%M:%S.%f'))
         return datetime.strftime(data, '%Y-%m-%dT%H:%M:%S')
@@ -87,9 +87,39 @@ class Servico:
 
     def executado(self):
         response = Controle.get({'servico': self.id})
+        if response.ok and not response.json():
+            return False
         if response.ok and response.json():
             return response.json()[0]['executado']
-        return False
+
+    def pode_integrar(self):
+        response = self.status()
+        if not response.json() and self.ativo():
+            return True
+        if self.em_execucao():
+            return False
+        if not self.executado():
+            return True
+        hoje, json = datetime.now(), response.json()[0]
+        fim_execucao = {
+            19: f'{json.get("fim_execucao")}.0'
+        }.get(len(json.get('fim_execucao')), json.get('fim_execucao'))
+        no_horario = hoje.time() >= datetime.strptime(
+            json.get('hora_agendamento', '01:00:00'), '%H:%M:%S',
+        ).time()
+        executou_hoje = all([
+            json.get('status') == 'S',
+            fim_execucao,
+            datetime.strptime(fim_execucao, '%Y-%m-%dT%H:%M:%S.%f').date() == hoje.date(),
+        ])
+        return all(
+            [
+                self.ativo(),
+                not self.executado(),
+                no_horario,
+                not executou_hoje,
+            ]
+        )
 
 
 class Controle:
@@ -99,8 +129,7 @@ class Controle:
         return mindset_request('GET', '/controle', query_params=filter_params)
 
     @staticmethod
-    def limpar(id_servico, executado):
-        json = {"_id_servico": id_servico, "executado": executado}
+    def limpar(json={}):
         return mindset_request('POST', '/controle/limpar_controles', json=json)
 
 
